# -*- coding: utf8 -*-
from fabric.operations import sudo

from django_fabric.base import App


class UwsgiApp(App):
    ini_files = {}

    def __init__(self, ini_files, *args, **kwargs):
        super(UwsgiApp, self).__init__(*args, **kwargs)
        self.ini_files = ini_files

    def restart_app(self, instance):
        sudo("touch %s" % self.ini_files[instance])



from setuptools import find_packages, setup

setup(
    name='django-fabric',
    version='1.1',
    author='Rolf Erik Lekang',
    author_email='rolf@mocco.no',
    url='http://mocco.no/django-fabric/',
    packages=find_packages(),
    description='a generic fabric utility class for django projects',
    classifiers=[
        "Programming Language :: Python",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Environment :: Web Environment",
        "Operating System :: OS Independent",
        "Natural Language :: English",
    ],
    include_package_data=True,
    zip_safe=False,
    install_requires=['fabric', 'django']
)
